This crate provides Usfm3 language support for the tree-sitter parsing library.
Typically, you will use the language function to add this language to a tree-sitter Parser, and then use the parser to parse some code:
let code = r#"\\id GEN\n\\c 1\n\\p\n\\v 1 In the beginning..
"#;
let mut parser = tree_sitter::Parser::new();
parser.set_language(&tree_sitter_usfm3::language()).expect("Error loading Usfm3 grammar");
let tree = parser.parse(code, None).unwrap();
assert!(!tree.root_node().has_error());Constants
- NODE_
TYPES - The content of the
node-types.jsonfile for this grammar.